Attribute VB_Name = "modCallBack"
Option Explicit

'---------------------------------------------------------------------------------------
' Module    : modCallBack
' Author    : mq
' Version   : 2007/Feb/5
' Copyright : deister electronic GmbH
'
' This file includes a sample implementation of a callback function used with
' the unikonDrv driver.
'
' This file is provided "as is" with no expressed or implied warranty.
' The author accepts no liability for any damage/loss of business that
' this product may cause.
'
'---------------------------------------------------------------------------------------

'---------------------------------------------------------------------------------------
' Function : myCallBackFunction
'
' To keep our application informed during an up/download (that may take several
' minutes) rsp. during an AutoDetect procedure we can install our own CallBack function.
' The unikon driver will call this function after each processed data record rsp. before
' checking a com port.
' Our function MUST take two LONG parameters and return a LONG.
' If our function returns a value of -1 the currently running up/download will
' immidiately be aborted and the pending function will return with value uni_CANCELED.
'
' To install our callback function we have to call the unikon driver with :
' retVal = uniSetCallBack(AddressOf myCallBackFunction)
'
' We MUST define our callback function in a BAS module. It is not possible to define
' it in a class or form module.
'
' In our test application here our callback function displays the statusInfo and
' the number of records processed in labels in our mainform.
'---------------------------------------------------------------------------------------

Public Function myCallBackFunction(ByVal statusInfo As Long, ByVal Counter As Long) As Long
Dim statusInfoText As String
Dim CounterText As String

  ' statusInfo tells what's going on
  Debug.Print statusInfo

  Select Case statusInfo
    Case SI_RECORD_UPLOADED
      statusInfoText = "uploading"
      CounterText = CStr(Counter) & " records processed"
    
    Case SI_RECORD_DOWNLOADED
      statusInfoText = "downloading"
      CounterText = CStr(Counter) & " records processed"
    
    Case SI_AUTODETECT_CHECK_PORT
      statusInfoText = "device detection"
      CounterText = "checking COM" & CStr(Counter)
    
    Case Else: statusInfoText = "unknown status"
  End Select
  
  ' Display text in mainform
  With frmMain
    .lblCallBackInfo(0) = statusInfoText
    .lblCallBackInfo(1) = CounterText
  End With
  
  ' If you want for some reason abort the current up/download return -1
  ' The pending function will immidiately return with a value of uni_CANCELED
  ' Any other return value has no effect
  
  ' myCallBackFunction = -1
End Function



